Skip to contents

Thin wrapper around update_nonmem_data() kept for internal callers. Always returns a single string regardless of the input shape.

Usage

change_nonmem_dataset(code, path)

Arguments

code

model code, either as single line string, or vector of lines

path

path of new dataset