Create a dictionary from given specs and default dictionary as fallback
parse_data_dictionary.RdCreate a dictionary from given specs and default dictionary as fallback
Usage
parse_data_dictionary(
dictionary,
default = list(ID = "ID", TIME = "TIME", DV = "DV", EVID = "EVID", AMT = "AMT", CMT =
"CMT", MDV = "MDV")
)