Add new $TABLE record to output variables
add_table_to_model.RdAdd new $TABLE record to output variables
Arguments
- model
pharmpy model object
- variables
character vector with variable names
- firstonly
add
FIRSTONLYparameter to $TABLE record- file
path to file, e.g.
sdtab- reload_dataset
should dataset be reloaded into the Pharmpy model object after updating the model. Default is TRUE, to ensure a proper Pharmpy model object, but can result in issues.