Clean / check the dataset before passing to model fitting tool
clean_modelfit_data.RdClean / check the dataset before passing to model fitting tool
Arguments
- model
pharmpy model object or NONMEM model code (character) or path to NONMEM model file.
- try_make_numeric
should function try to turn character columns into numeric columns? If
FALSEwill just set all values to 0 (but retain column to avoid issues).- data
a data.frame (if not specified, will use
datasetobject inmodel).- verbose
verbose output?