Helper function to get the name of the template modelfile to load, based on route and ODE / analytical
get_template_modelfile.RdHelper function to get the name of the template modelfile to load, based on route and ODE / analytical
Arguments
- route
route of administration. One of
"auto"(default),"oral","sc","im","extravascular", or"iv". When"auto", the route is inferred fromdataby comparing theCMTof dose events (EVID=1) to theCMTof observation events (EVID=0): if any dose compartment is not also an observation compartment (e.g. doses inCMT=1, observations inCMT=2), the route is set to"oral"; otherwise"iv". Falls back to"iv"ifdataisNULLor the dataset lacks the requiredCMT/EVIDcolumns.- n_cmt
number of elimination and distribution compartments. Default is 1, i.e. no peripheral distributions.
- force_ode
force creation of a model with ODEs, even though the model is linear. Can be
FALSE(default),TRUE, or ADVAN number (for NONMEM models). In the latter case, options are either6,9, or13.