Helper function to get the name of the template modelfile to load, based on route and ODE / analytical
get_template_modelfile.RdHelper function to get the name of the template modelfile to load, based on route and ODE / analytical
Arguments
- route
route of administration, either
oraloriv- n_cmt
number of elimination and distribution compartments. Default is 1, i.e. no peripheral distributions.
- force_ode
force creation of a model with ODEs, even though the model is linear. Can be
FALSE(default),TRUE, or ADVAN number (for NONMEM models). In the latter case, options are either6,9, or13.