Set model to be a simulation (only) model
set_simulation_clean.RdThis function is a drop-in replacement of the Pharmpy set_simulation()
function. The pharmpy function works fine in many instances, but in some
cases it modifies the variable declarations (e.g. redeclares variables in $PK
that are declared in $DES, which can lead to invalid models that are not
accepted by NONMEM).