Strip surrounding quote characters from data.frame column names
unquote_column_names.RdPharmpy rejects column names that are not valid Python identifiers, and NONMEM misinterprets CSV headers that start with a quote character. This helper removes a single pair of matching surrounding single or double quotes from each column name.